@@ -39,21 +39,21 @@ module Nanoc
         view_context =
           Nanoc::Core::ViewContextForShell.new(
             items: site.items,
-            reps: reps,
+            reps:,
           )
 
         context = {
           items: Nanoc::Core::PostCompileItemCollectionView.new(site.items, view_context),
           layouts: Nanoc::Core::LayoutCollectionView.new(site.layouts, view_context),
           config: Nanoc::Core::ConfigView.new(site.config, view_context),
-          output_filenames: output_filenames,
+          output_filenames:,
         }
 
         new(context)
       end
 
       def initialize(context)
-        super(context)
+        super
 
         @issues = Set.new
       end
