@@ -181,7 +181,7 @@ module Nanoc
         pieces = pieces[0, pieces.size - 1] || []
         root = Nanoc::CLI.root_command
         supercommand = pieces.reduce(root) do |cmd, piece|
-          cmd.nil? ? nil : cmd.command_named(piece)
+          cmd&.command_named(piece)
         end
 
         # Add to supercommand
