@@ -5,7 +5,7 @@ module Nanoc
     # @api private
     module Transform
       module Port
-        RANGE = (0x0001..0xffff).freeze
+        RANGE = (0x0001..0xffff)
 
         def self.call(data)
           Integer(data).tap do |int|
