@@ -8,7 +8,7 @@ module Nanoc
 
       contract C::KeywordArgs[config: Nanoc::Core::Configuration] => C::Any
       def initialize(config:)
-        super(Nanoc::Core::Store.tmp_path_for(config: config, store_name: 'outdatedness'), 2)
+        super(Nanoc::Core::Store.tmp_path_for(config:, store_name: 'outdatedness'), 2)
 
         @outdated_refs = Set.new
       end
