@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 describe 'meta', chdir: false do
+  # rubocop:disable RSpec/ExampleLength
   it 'is covered by specs' do
     regular_files = Dir['lib/nanoc/core/**/*.rb']
     regular_file_base_names = regular_files.map { |fn| fn.gsub(/^lib\/nanoc\/core\/|\.rb$/, '') }
@@ -36,8 +37,8 @@ describe 'meta', chdir: false do
       outdatedness_rules/attributes_modified
       outdatedness_rules/code_snippets_modified
       outdatedness_rules/content_modified
-      outdatedness_rules/item_collection_extended
-      outdatedness_rules/layout_collection_extended
+      outdatedness_rules/item_added
+      outdatedness_rules/layout_added
       outdatedness_rules/not_written
       outdatedness_rules/rules_modified
       outdatedness_rules/uses_always_outdated_filter
@@ -62,6 +63,7 @@ describe 'meta', chdir: false do
     ignored_spec_file_base_names = %w[
       errors/dependency_cycle
       outdatedness_rules
+      item_rep_selector/item_rep_priority_queue
     ]
 
     effective_regular_file_base_names =
@@ -88,4 +90,5 @@ describe 'meta', chdir: false do
       !content.match?(/\b(puts|warn)\b/) && !content.match?(/\$std(err|out)/)
     end)
   end
+  # rubocop:enable RSpec/ExampleLength
 end
