@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 describe Nanoc::Core::ChecksumStore do
-  let(:store) { described_class.new(config: config, objects: objects) }
+  let(:store) { described_class.new(config:, objects:) }
 
   let(:config) { Nanoc::Core::Configuration.new(dir: Dir.getwd).with_defaults }
 
