@@ -16,29 +16,29 @@ describe Nanoc::DartSass::Filter::NanocImporter do
   let(:view_context) do
     Nanoc::Core::ViewContextForCompilation.new(
       reps: Nanoc::Core::ItemRepRepo.new,
-      items: items,
-      dependency_tracker: dependency_tracker,
-      compilation_context: compilation_context,
-      compiled_content_store: compiled_content_store,
+      items:,
+      dependency_tracker:,
+      compilation_context:,
+      compiled_content_store:,
     )
   end
 
   let(:compilation_context) do
     Nanoc::Core::CompilationContext.new(
-      action_provider: action_provider,
-      reps: reps,
-      site: site,
-      compiled_content_cache: compiled_content_cache,
-      compiled_content_store: compiled_content_store,
+      action_provider:,
+      reps:,
+      site:,
+      compiled_content_cache:,
+      compiled_content_store:,
     )
   end
 
   let(:compiled_content_store) { Nanoc::Core::CompiledContentStore.new }
-  let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config: config) }
+  let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config:) }
 
   let(:site) do
     Nanoc::Core::Site.new(
-      config: config,
+      config:,
       code_snippets: [],
       data_source: Nanoc::Core::InMemoryDataSource.new(items, layouts),
     )
