@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 module Nanoc::Helpers
-  # @see https://nanoc.ws/doc/reference/helpers/#blogging
+  # @see https://nanoc.app/doc/reference/helpers/#blogging
   module Blogging
     # @return [Array]
     def articles
@@ -120,8 +120,8 @@ module Nanoc::Helpers
           xml.updated(updated.__nanoc_to_iso8601_time)
 
           # Add links
-          xml.link(rel: 'alternate', href: (alt_link || root_url), type: 'text/html')
-          xml.link(rel: 'self',      href: feed_url,               type: 'application/atom+xml')
+          xml.link(rel: 'alternate', href: alt_link || root_url, type: 'text/html')
+          xml.link(rel: 'self',      href: feed_url,             type: 'application/atom+xml')
 
           # Add author information
           xml.author do
