@@ -6,10 +6,6 @@ describe Nanoc::DataSources::Filesystem, site: true do
   let(:params) { {} }
   let(:site) { Nanoc::Core::SiteLoader.new.new_from_cwd }
 
-  before { Timecop.freeze(now) }
-
-  after { Timecop.return }
-
   describe '#load_objects' do
     subject { data_source.send(:load_objects, dir_with_objects, klass) }
 
