@@ -17,10 +17,10 @@ describe Nanoc::OrigCLI::Commands::ShowRules, site: true, stdio: true do
     let(:site) do
       double(
         :site,
-        items: items,
-        layouts: layouts,
-        compiler: compiler,
-        config: config,
+        items:,
+        layouts:,
+        compiler:,
+        config:,
       )
     end
 
@@ -120,7 +120,7 @@ describe Nanoc::OrigCLI::Commands::ShowRules, site: true, stdio: true do
     it 'writes item and layout rules to stdout' do
       expect(runner).to receive(:load_site).and_return(site)
       expect(Nanoc::Core::Compiler).to receive(:new_for).with(site).and_return(compiler)
-      expect(compiler).to receive(:run_until_reps_built).and_return(reps: reps)
+      expect(compiler).to receive(:run_until_reps_built).and_return(reps:)
       expect(Nanoc::RuleDSL::ActionProvider).to receive(:for).with(site).and_return(action_provider)
       expect { subject }.to output(expected_out).to_stdout
     end
