@@ -41,7 +41,7 @@ class Nanoc::Filters::PandocTest < Nanoc::TestCase
 
       # Run filter
       args = [:s, { f: :markdown, to: :html }, 'wrap=none', :toc]
-      result = filter.setup_and_run("# Heading\n", args: args)
+      result = filter.setup_and_run("# Heading\n", args:)
 
       assert_match '<nav id="TOC"', result
       assert_match(%r{<h1 id="heading">Heading</h1>\s*}, result)
